@@ -52,15 +52,15 @@ void interface_create_mainwindow()  {
 
 	/* icons */
 	GList *iconlist = NULL;
-	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_ICON_DIR "/128x128" ICON_PATH_SUFFIX, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_ICON_DIR "/128x128/apps/gtkatlantic.png", NULL);
 	if (pixbuf) iconlist = g_list_append(iconlist, pixbuf);
-	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_ICON_DIR "/64x64" ICON_PATH_SUFFIX, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_ICON_DIR "/64x64/apps/gtkatlantic.png", NULL);
 	if (pixbuf) iconlist = g_list_append(iconlist, pixbuf);
-	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_ICON_DIR "/48x48" ICON_PATH_SUFFIX, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_ICON_DIR "/48x48/apps/gtkatlantic.png", NULL);
 	if (pixbuf) iconlist = g_list_append(iconlist, pixbuf);
-	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_ICON_DIR "/32x32" ICON_PATH_SUFFIX, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_ICON_DIR "/32x32/apps/gtkatlantic.png", NULL);
 	if (pixbuf) iconlist = g_list_append(iconlist, pixbuf);
-	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_ICON_DIR "/16x16" ICON_PATH_SUFFIX, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_ICON_DIR "/16x16/apps/gtkatlantic.png", NULL);
 	if (pixbuf) iconlist = g_list_append(iconlist, pixbuf);
 	gtk_window_set_default_icon_list(iconlist);
 
@@ -190,7 +190,7 @@ void interface_create_mainwindow()  {
 	}
 
 	GdkRGBA rgba;
-	gtk_style_context_get_color(stylecontext, GTK_STATE_NORMAL, &rgba);
+	gtk_style_context_get_color(stylecontext, GTK_STATE_FLAG_NORMAL, &rgba);
 	if (rgba.red * 0.2126 + rgba.green * 0.7152 + rgba.blue * 0.0722 > 0.5) {
 		/* Dark theme */
 		global->bg_green = "#007000";
@@ -1181,59 +1181,21 @@ void interface_create_auctionbox(gint32 auctionid, gint32 estateid)  {
 /* create about window */
 void interface_create_aboutwin()
 {
-	GtkWidget *AboutDlg;
-	GtkWidget *Label;
-	GtkWidget *VBox;
+	const char *const authors[] = {
+		"Sylvain Rochet <gradator@gradator.net>",
+		"Xavier Amado <xavier@blackbloodstudios.com>",
+		NULL
+	};
 
-	gchar *text;
-
-	AboutDlg = gtk_dialog_new_with_buttons("About gtkAtlantic", NULL,
-			GTK_DIALOG_MODAL, "_OK", GTK_RESPONSE_ACCEPT,
-			NULL);
-	gtk_window_set_default_size(GTK_WINDOW(AboutDlg), 200, 0);
-	gtk_window_set_transient_for(GTK_WINDOW(AboutDlg), GTK_WINDOW(global->MainWin));
-	g_signal_connect_swapped(G_OBJECT(AboutDlg), "response",
-			G_CALLBACK(gtk_widget_destroy), G_OBJECT(AboutDlg));
-
-	/* Create a VBox with a border */
-	VBox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
-	gtk_container_set_border_width(GTK_CONTAINER(VBox), 10);
-	gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(AboutDlg))), VBox);
-
-	/* name */
-	text = g_strdup_printf("<span size=\"xx-large\"><b>GtkAtlantic %s</b></span>", VERSION);
-
-	Label = gtk_label_new(text);
-	gtk_label_set_use_markup(GTK_LABEL(Label), TRUE);
-	gtk_box_pack_start(GTK_BOX(VBox), Label, FALSE,
-			FALSE, 5);
-
-	g_free(text);
-
-	/* web site */
-	Label = gtk_label_new("http://gtkatlantic.gradator.net");
-	gtk_box_pack_start(GTK_BOX(VBox), Label, FALSE,	FALSE, 5);
-
-	/* license */
-	Label = gtk_label_new("This software is distributed under the GPL Version 2 or any later version");
-	gtk_label_set_line_wrap(GTK_LABEL(Label), TRUE);
-	gtk_box_pack_start(GTK_BOX(VBox), Label, FALSE,	FALSE, 10);
-
-	/* author */
-	Label = gtk_label_new("<b>Authors:</b>");
-	gtk_label_set_use_markup(GTK_LABEL(Label), TRUE);
-	gtk_box_pack_start(GTK_BOX(VBox), Label, FALSE, FALSE, 0);
-
-	Label = gtk_label_new("Sylvain Rochet (gradator@gradator.net)");
-	gtk_box_pack_start(GTK_BOX(VBox), Label, FALSE, FALSE, 0);
-	Label = gtk_label_new("Xavier Amado (xavier@blackbloodstudios.com)");
-        gtk_box_pack_start(GTK_BOX(VBox), Label, FALSE, FALSE, 0);
-
-	/* IRC */
-	Label = gtk_label_new("irc.freenode.net #gtkatlantic");
-	gtk_box_pack_start(GTK_BOX(VBox), Label, FALSE, FALSE, 10);
-
-	gtk_widget_show_all(AboutDlg);
+	gtk_show_about_dialog(GTK_WINDOW(global->MainWin),
+		"authors", authors,
+		"comments", "irc.freenode.net #gtkatlantic",
+		"license-type", GTK_LICENSE_GPL_2_0,
+		"logo-icon-name", "gtkatlantic",
+		"program-name", "GtkAtlantic",
+		"version", VERSION,
+		"website", "http://gtkatlantic.gradator.net",
+		NULL);
 }
 
 
